
#ifndef __csd_marshal_MARSHAL_H__
#define __csd_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,STRING (csd-marshal.list:1) */
G_GNUC_INTERNAL void csd_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

G_END_DECLS

#endif /* __csd_marshal_MARSHAL_H__ */

